Learn R Programming

gfilmm (version 2.0.5)

gfiCDF: Fiducial cumulative distribution function

Description

Fiducial cumulative distribution function of a parameter of interest.

Usage

gfiCDF(parameter, gfi)

Value

The fiducial cumulative distribution function of the parameter.

Arguments

parameter

a right-sided formula defining the parameter of interest, like ~ sigma_error/`(Intercept)`

gfi

a gfilmm object (output of gfilmm or gfilmmPredictive)

Examples

Run this code
h <- 0.01
gfi <- gfilmm(
  ~ cbind(yield-h, yield+h), ~ 1, ~ block, data = npk, N = 5000, nthreads = 2
)
F <- gfiCDF(~ sqrt(sigma_block^2 + sigma_error^2)/`(Intercept)`, gfi)
plot(F, xlim = c(0, 0.3), main = "Coefficient of variation", 
     ylab = expression("Pr("<="x)"))
F(0.2)

Run the code above in your browser using DataLab