Learn R Programming

gfilmm (version 2.0.5)

gfiQuantile: Quantiles of a fiducial distribution

Description

Quantiles of the fiducial distribution of a parameter of interest.

Usage

gfiQuantile(parameter, gfi, probs)

Value

Numeric vector of quantiles, of the same length as probs.

Arguments

parameter

a right-sided formula defining the parameter of interest, like ~ sigma_error/`(Intercept)`

gfi

a gfilmm object (output of gfilmm or gfilmmPredictive)

probs

numeric vector of probabilities

Examples

Run this code
h <- 0.01
gfi <- gfilmm(
  ~ cbind(yield-h, yield+h), ~ 1, ~ block, data = npk, N = 5000, nthreads = 2
)
gfiQuantile(~ sqrt(sigma_block^2 + sigma_error^2), gfi, c(25, 50, 75)/100)

Run the code above in your browser using DataLab