powered by
Quantiles of the fiducial distribution of a parameter of interest.
gfiQuantile(parameter, gfi, probs)
Numeric vector of quantiles, of the same length as probs.
probs
a right-sided formula defining the parameter of interest, like ~ sigma_error/`(Intercept)`
~ sigma_error/`(Intercept)`
a gfilmm object (output of gfilmm or gfilmmPredictive)
gfilmm
gfilmmPredictive
numeric vector of probabilities
h <- 0.01 gfi <- gfilmm( ~ cbind(yield-h, yield+h), ~ 1, ~ block, data = npk, N = 5000, nthreads = 2 ) gfiQuantile(~ sqrt(sigma_block^2 + sigma_error^2), gfi, c(25, 50, 75)/100)
Run the code above in your browser using DataLab